@@ -65,7 +65,7 @@ class DBConnect():
                 'page_size': str,  'current': str,  'columns': str,  'sort_order': str,
                 'filtered_value': str, 'start_date': str, 'end_date': str,
             },
-            optional={'start_date': None, 'end_date': None})
+            optional={'start_date': '', 'end_date': ''})
         param = parameter.param_url
         try:
             page_size = int(param['page_size'])  # 每页条数
